==> openwebmail-2.32.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/pt/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Cabealho 1": "h1",
		"Cabealho 2": "h2",
		"Cabealho 3": "h3",
		"Cabealho 4": "h4",
		"Cabealho 5": "h5",
		"Cabealho 6": "h6",
		"Normal": "p",
		"Endereo": "address",
		"Pr-Formatado": "pre"
	},

	tooltips: {
		bold:           "Negrito",
		italic:         "Itlico",
		underline:      "Sublinhado",
		strikethrough:  "Rasurado",
		subscript:      "Inferior  linha",
		superscript:    "Superior  linha",
		justifyleft:    "Alinhar  esquerda",
		justifycenter:  "Ao Centro",
		justifyright:   "Alinhar  direita",
		justifyfull:    "Justificar",
		insertorderedlist:    "Lista Ordenada",
		insertunorderedlist:  "Lista com marcadores",
		outdent:        "Diminuir avano",
		indent:         "Aumentar Avano",
		forecolor:      "Cor do tipo de fonte",
		hilitecolor:    "Cor do fundo",
		horizontalrule: "Rgua Horizontal",
		createlink:     "Inserir Link",
		insertimage:    "Inserir Imagem",
		insertsound:    "Inserir Som",
		inserttable:    "Inserir Tabela",
		htmlmode:       "Ver fonte HTML",
		popupeditor:    "Ampliar Editor",
		about:          "Sobre este editor",
		showhelp:       "Ajuda",
		textindicator:  "Estilo Actual",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/pt/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Cabealho 1": "h1",
		"Cabealho 2": "h2",
		"Cabealho 3": "h3",
		"Cabealho 4": "h4",
		"Cabealho 5": "h5",
		"Cabealho 6": "h6",
		"Normal": "p",
		"Endereo": "address",
		"Pr-Formatado": "pre"
	},

	tooltips: {
		bold:           "Negrito",
		italic:         "Itlico",
		underline:      "Sublinhado",
		strikethrough:  "Rasurado",
		subscript:      "Inferior  linha",
		superscript:    "Superior  linha",
		justifyleft:    "Alinhar  esquerda",
		justifycenter:  "Ao Centro",
		justifyright:   "Alinhar  direita",
		justifyfull:    "Justificar",
		insertorderedlist:    "Lista Ordenada",
		insertunorderedlist:  "Lista com marcadores",
		outdent:        "Diminuir avano",
		indent:         "Aumentar Avano",
		forecolor:      "Cor do tipo de fonte",
		hilitecolor:    "Cor do fundo",
		inserthorizontalrule: "Rgua Horizontal",
		createlink:     "Inserir Link",
		insertimage:    "Inserir Imagem",
		insertsound:    "Inserir Som",
		inserttable:    "Inserir Tabela",
		htmlmode:       "Ver fonte HTML",
		popupeditor:    "Ampliar Editor",
		about:          "Sobre este editor",
		showhelp:       "Ajuda",
		textindicator:  "Estilo Actual",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};
